@@ -113,7 +113,7 @@ uint16_t iarduino_I2C_TDS::getFrequency		(void				){																//	Пара
 				_readBytes(REG_TDS_FREQUENCY_L, 2);																				//	Читаем 2 байта из модуля начиная регистра «REG_TDS_FREQUENCY_L» в массив «data».
 			//	Возвращаем результат:																							//
 				return ((uint16_t)data[1]<<8) | data[0];																		//	Собираем результат из массива «data» и возвращаем полученное значение в Гц.
-			}																													//	
+			}																													//
 			return 0;																											//	Возвращаем ошибку.
 }																																//
 																																//
@@ -155,6 +155,18 @@ bool	iarduino_I2C_TDS::setCalibration	(uint8_t num, uint16_t tds){
 			}																													//
 }																																//
 																																//
+//		Получение текущей стадии калибровки модуля:																				//	Возвращаемое значение:	стадия калибровки (0-нет, 1, 2)
+uint8_t	iarduino_I2C_TDS::getCalibration	(void){																				//	Параметр:				отсутствует.
+			if(valAddr){																										//	Если модуль был инициализирован, то ...
+			//	Читаем данные из модуля:																						//
+				_readBytes(REG_TDS_CALIBRATION, 1);																				//	Читаем 1 байт из регистра «REG_TDS_CALIBRATION» в массив «data».
+			//	Возвращаем результат:																							//
+				if(data[0]&TDS_FLG_STATUS_1){return 1;}																			//	Выполняется 1 стадия калибровки.
+				if(data[0]&TDS_FLG_STATUS_2){return 2;}																			//	Выполняется 2 стадия калибровки.
+			}																													//
+			return 0;																											//	Калибровка не выполняется.
+}																																//
+																																//
 //		Получение концентрации раствора для калибровки модуля с кнопки:															//	Возвращаемое значение:	количество растворённых твёрдых веществ в калибровочной жидкости.
 uint16_t iarduino_I2C_TDS::getKnownTDS		(uint8_t num){																		//	Параметр:				стадия калибровки (1 или 2).
 			if(valAddr){																										//	Если модуль был инициализирован, то ...
@@ -165,7 +177,7 @@ uint16_t iarduino_I2C_TDS::getKnownTDS		(uint8_t num){																		//	Па
 			//	Возвращаем результат:																							//
 				uint16_t result = ((uint16_t)data[1]<<8) | data[0];																//	Собираем результат из массива «data» в переменную «result».
 				return result;																									//	Возвращаем результат.
-			}																													//	
+			}																													//
 			return 0;																											//	Возвращаем ошибку.
 }																																//
 																																//
@@ -195,7 +207,7 @@ float	iarduino_I2C_TDS::getKa				(void){																				//	Параметр:
 			//	Возвращаем результат:																							//
 				int32_t result = ((uint32_t)(data[2]&0x7F)<<16) | ((uint32_t)data[1]<<8) | data[0];								//	Собираем результат из массива «data» в переменную «result».
 				return ((float)result)/100.0f;																					//	Возвращаем результат, преобразовав значение из сотых долей.
-			}																													//	
+			}																													//
 			return 0;																											//	Возвращаем ошибку.
 }																																//
 																																//
@@ -226,7 +238,7 @@ float	iarduino_I2C_TDS::getKb				(void){																				//	Параметр:
 			//	Возвращаем результат:																							//
 				uint16_t result = ((uint16_t)data[1]<<8) | data[0];																//	Собираем результат из массива «data» в переменную «result».
 				return ((float)result)/-1000.0f;																				//	Возвращаем результат, преобразовав значение из тысячных долей и добавив отрицательный знак.
-			}																													//	
+			}																													//
 			return 0;																											//	Возвращаем ошибку.
 }																																//
 																																//
@@ -257,7 +269,7 @@ float	iarduino_I2C_TDS::getKt				(void){																				//	Параметр:
 			//	Возвращаем результат:																							//
 				uint16_t result = ((uint16_t)data[1]<<8) | data[0];																//	Собираем результат из массива «data» в переменную «result».
 				return ((float)result)/10000.0f;																				//	Возвращаем результат, преобразовав значение из десятитысячных долей.
-			}																													//	
+			}																													//
 			return 0;																											//	Возвращаем ошибку.
 }																																//
 																																//
@@ -285,7 +297,7 @@ float	iarduino_I2C_TDS::getKp				(void){																				//	Параметр:
 				_readBytes(REG_TDS_Kp, 1);																						//	Читаем 1 байт из регистра «REG_TDS_Kp» в массив «data».
 			//	Возвращаем результат:																							//
 				return ((float)data[0])/100.0f;																					//	Возвращаем результат, преобразовав значение из сотых долей.
-			}																													//	
+			}																													//
 			return 0;																											//	Возвращаем ошибку.
 }																																//
 																																//
@@ -326,7 +338,7 @@ float	iarduino_I2C_TDS::get_T				(void){																				//	Параметр:
 				_readBytes(REG_TDS_T, 1);																						//	Читаем 1 байт из регистра «REG_TDS_T» в массив «data».
 			//	Возвращаем результат:																							//
 				return ((float)data[0])/4.0f;																					//	Возвращаем результат, преобразовав значение из целого числа с эквивалентным шагом 0.25°С.
-			}																													//	
+			}																													//
 			return 0;																											//	Возвращаем ошибку.
 }																																//
 																																//
@@ -352,7 +364,7 @@ uint32_t iarduino_I2C_TDS::getRo			(void){																				//	Парамет
 				_readBytes(REG_TDS_Ro, 3);																						//	Читаем 3 байта из регистра «REG_TDS_Ro» в массив «data».
 			//	Возвращаем результат:																							//
 				return ((uint32_t)data[2]<<16) | ((uint32_t)data[1]<<8) | data[0];												//	Собираем результат из массива «data» и возвращаем полученное значение в Ом.
-			}																													//	
+			}																													//
 			return 0;																											//	Возвращаем ошибку.
 }																																//
 																																//
@@ -363,7 +375,7 @@ float	iarduino_I2C_TDS::getVout			(void){																				//	Параметр
 				_readBytes(REG_TDS_Vout, 2);																					//	Читаем 2 байта из регистра «REG_TDS_Vout» в массив «data».
 			//	Возвращаем результат:																							//
 				return (float)(((uint16_t)data[1]<<8) | data[0])/10000.0f;														//	Собираем результат из массива «data» и возвращаем полученное значение в В.
-			}																													//	
+			}																													//
 			return 0;																											//	Возвращаем ошибку.
 }																																//
 																																//
@@ -374,7 +386,7 @@ uint16_t iarduino_I2C_TDS::get_S			(void){																				//	Парамет
 				_readBytes(REG_TDS_S, 2);																						//	Читаем 2 байта из регистра «REG_TDS_S» в массив «data».
 			//	Возвращаем результат:																							//
 				return ((uint16_t)data[1]<<8) | data[0];																		//	Собираем результат из массива «data» и возвращаем полученное значение в мкСм/см.
-			}																													//	
+			}																													//
 			return 0;																											//	Возвращаем ошибку.
 }																																//
 																																//
@@ -385,7 +397,7 @@ uint16_t iarduino_I2C_TDS::getEC			(void){																				//	Парамет
 				_readBytes(REG_TDS_EC, 2);																						//	Читаем 2 байта из регистра «REG_TDS_EC» в массив «data».
 			//	Возвращаем результат:																							//
 				return ((uint16_t)data[1]<<8) | data[0];																		//	Собираем результат из массива «data» и возвращаем полученное значение в мкСм/см.
-			}																													//	
+			}																													//
 			return 0;																											//	Возвращаем ошибку.
 }																																//
 																																//
@@ -396,7 +408,7 @@ uint16_t iarduino_I2C_TDS::getTDS			(void){																				//	Парамет
 				_readBytes(REG_TDS_TDS, 2);																						//	Читаем 2 байта из регистра «REG_TDS_TDS» в массив «data».
 			//	Возвращаем результат:																							//
 				return ((uint16_t)data[1]<<8) | data[0];																		//	Собираем результат из массива «data» и возвращаем полученное значение в мкСм/см.
-			}																													//	
+			}																													//
 			return 0;																											//	Возвращаем ошибку.
 }																																//
 																																//
@@ -421,4 +433,4 @@ bool	iarduino_I2C_TDS::_writeBytes		(uint8_t reg, uint8_t sum, uint8_t num){
 			delay(10);																											//	Ждём применения модулем записанных данных.
 			return result;																										//	Возвращаем результат записи (true/false).
 }																																//
-																																//
\ No newline at end of file
+																																//
