@@ -1,5 +1,5 @@
 //	Библиотека для работы с Trema модулем TDS/EC-метр, I2C-flash для Arduino: https://iarduino.ru/shop/Sensory-Datchiki/solemer-tds-ec-flash-i2c.html
-//  Версия: 1.1.0
+//  Версия: 1.2.0
 //  Последнюю версию библиотеки Вы можете скачать по ссылке: https://iarduino.ru/file/556.html
 //  Подробное описание функций бибилиотеки доступно по ссылке: https://wiki.iarduino.ru/page/TDS-EC-i2c/
 //  Библиотека является собственностью интернет магазина iarduino.ru и может свободно использоваться и распространяться!
@@ -49,6 +49,8 @@
 #define			REG_TDS_EC				0x22																	//	Адрес регистра содержащего удельную электропроводность «EC» в мкСм/см приведённую к опорной температуре T°С (два байта).
 #define			REG_TDS_TDS				0x24																	//	Адрес регистра содержащего количество растворенных в воде примесей «TDS» в ppm = мг/л (два байта).
 //				Позиция битов и флагов:																			//
+#define			TDS_FLG_STATUS_2		0x80																	//	Флаг  регистра REG_TDS_CALIBRATION информирует о выполнении 2 стадии калибровки.
+#define			TDS_FLG_STATUS_1		0x40																	//	Флаг  регистра REG_TDS_CALIBRATION информирует о выполнении 1 стадии калибровки.
 #define			TDS_BIT_CALC_2			0x02																	//	Бит   регистра REG_TDS_CALIBRATION указывает модулю выполнить 2 стадию калибровки.
 #define			TDS_BIT_CALC_1			0x01																	//	Бит   регистра REG_TDS_CALIBRATION указывает модулю выполнить 1 стадию калибровки.
 																												//
@@ -71,6 +73,7 @@ class iarduino_I2C_TDS{																							//
 		uint16_t			getFrequency		(void				);											//	Объявляем  функцию получения    частоты переменного тока для измерений	(Параметр:  отсутствует).
 		bool				setFrequency		(uint16_t			);											//	Объявляем  функцию установки    частоты переменного тока для измерений	(Параметр:  частота от 50 до 5000Гц).
 		bool				setCalibration		(uint8_t, uint16_t	);											//	Объявляем  функцию запуска      калибровки модуля						(Параметры: стадия 1 или 2, концентрация калибровочной жидкости от 0 до 10000ppm).
+		uint8_t				getCalibration		(void				);											//	Объявляем  функцию получения    текущей стадии калибровки модуля		(Параметр:  отсутствует).
 		uint16_t			getKnownTDS			(uint8_t			);											//	Объявляем  функцию получения    концентрации для калибр модуля с кнопки	(Параметр:  стадия 1 или 2).
 		bool				setKnownTDS			(uint8_t, uint16_t	);											//	Объявляем  функцию установки    концентрации для калибр модуля с кнопки	(Параметр:  стадия 1 или 2, концентрация калибровочной жидкости от 0 до 10000ppm).
 		float				getKa				(void				);											//	Объявляем  функцию получения    множителя степенной функции				(Параметр:  отсутствует).
